import { Component, Input, ViewChild, Injectable, EventEmitter, Inject, Output, NgModule, ViewEncapsulation, NO_ERRORS_SCHEMA } from '@angular/core';
import { MatPaginator, MatPaginatorModule } from '@angular/material/paginator';
import { MatSort, MatSortModule } from '@angular/material/sort';
import { CdkTableModule } from '@angular/cdk/table';
import { Validators, FormBuilder, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { LABEL_ASPECT } from '@yukawa/chain-main-angular-core';
import { BehaviorSubject, Subject, fromEvent } from 'rxjs';
import _ from 'lodash';
import { debounceTime, distinctUntilChanged, map } from 'rxjs/operators';
import { MatTableModule } from '@angular/material/table';
import { MatChipsModule } from '@angular/material/chips';
import { ColorPickerModule } from 'ngx-color-picker';
import { TranslateModule } from '@ngx-translate/core';
import { CommonModule } from '@angular/common';
import { MatListModule } from '@angular/material/list';
import { MatIconModule } from '@angular/material/icon';
import { MatSelectModule } from '@angular/material/select';
import { MatInputModule } from '@angular/material/input';
import { MatButtonModule } from '@angular/material/button';
import { ClickOutsideModule } from 'ng-click-outside';
import { FlexModule, FlexLayoutModule } from '@angular/flex-layout';
import { MatCardModule } from '@angular/material/card';
import { MatTooltipModule } from '@angular/material/tooltip';
import { MatToolbarModule } from '@angular/material/toolbar';
import { ChainBaseComp } from '@yukawa/chain-base-angular-comp';
import { QueryTableSource } from '@yukawa/chain-base-angular-store';
import { HttpClient } from '@angular/common/http';
import { RestAspect, ConfigService } from '@yukawa/chain-base-angular-client';

const TAG = 'LabelTableComponent';
class LabelTableComponent {
    constructor() {
        this.displayedColumns = ['name'];
    }
    ngOnInit() {
        console.debug(TAG, this.dataSource);
    }
}
LabelTableComponent.decorators = [
    { type: Component, args: [{
                selector: 'chain-main-label-table',
                template: "<div class=\"table-layout-1\" *ngIf=\"dataSource\">\n\n  <mat-table #table [dataSource]=\"dataSource\">\n    <!-- username Column -->\n    <ng-container matColumnDef=\"name\">\n      <mat-header-cell *matHeaderCellDef>{{'HEADER.NAME' | translate}}</mat-header-cell>\n      <mat-cell *matCellDef=\"let row\">\n        <mat-chip-list>\n          <mat-chip [ngStyle]=\"{'background-color': row?.colorCode}\">{{row.name}}</mat-chip>\n        </mat-chip-list>\n      </mat-cell>\n    </ng-container>\n\n    <mat-header-row *matHeaderRowDef=\"displayedColumns\"></mat-header-row>\n    <mat-row *matRowDef=\"let row; columns: displayedColumns;\"></mat-row>\n  </mat-table>\n\n</div>\n",
                styles: [""]
            },] }
];
/** @nocollapse */
LabelTableComponent.ctorParameters = () => [];
LabelTableComponent.propDecorators = {
    displayedColumns: [{ type: Input }],
    labelFilter: [{ type: Input }],
    dataSource: [{ type: Input }],
    paginator: [{ type: ViewChild, args: [MatPaginator, { static: true },] }],
    sort: [{ type: ViewChild, args: [MatSort, { static: true },] }]
};

class LabelEditService {
    constructor() {
        this._labelManagementShown = new BehaviorSubject(false);
        this._selectedLabels = new BehaviorSubject([]);
    }
    showLabelManagement() {
        this.labelManagementShown.next(true);
    }
    hideLabelManagement() {
        this.labelManagementShown.next(false);
    }
    toggleLabelManagement() {
        this.labelManagementShown.next(!this.labelManagementShown.value);
    }
    get labelManagementShown() {
        return this._labelManagementShown;
    }
    get selectedLabels() {
        return this._selectedLabels;
    }
    setSelectedLabels(labels) {
        this.selectedLabels.next(labels);
    }
}
LabelEditService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
LabelEditService.ctorParameters = () => [];

const TAG$1 = "LabelingComponent";
class LabelingComponent {
    constructor(_formBuilder, labelEditService, labelAspect) {
        this._formBuilder = _formBuilder;
        this.labelEditService = labelEditService;
        this.labelAspect = labelAspect;
        this.labelAdded = new EventEmitter();
        this.navigateToAllLabels = new EventEmitter();
        this.debouncer = new Subject();
        this.showAddLabelBox = false;
        this.debouncer.pipe(debounceTime(100))
            .subscribe(color => this.newLabel.get("colorCode").patchValue(color));
    }
    ngOnInit() {
        this.selectedLabels = this.labelEditService.selectedLabels;
        this.newLabel = this._formBuilder.group({
            name: [null, [Validators.required]],
            colorCode: [null, [Validators.required]]
        });
        if (!this.labelList && this.labelAspect) {
            this.labelAspect.queryLabel({ pager: { pageSize: 10000, firstResult: 0 } })
                .subscribe(value => {
                this.labelList = value.items;
            });
        }
    }
    createNewLabel() {
        console.debug(TAG$1, "new label: ", this.newLabel.value);
        this.labelAspect.createLabel(this.newLabel.value)
            .subscribe(value => {
            this.labelList.push(value);
            this.labelAdded.emit(this.newLabel.value);
            this.newLabel.reset();
            this.showAddLabelBox = false;
        });
    }
    deleteLabel(event, labelId) {
        event.stopPropagation();
        this.labelAspect.deleteLabel(labelId).subscribe(() => {
            this.labelList.splice(this.labelList.map(label => label.id).indexOf(labelId), 1);
        });
    }
    colorPickerChange(color) {
        this.debouncer.next(color);
    }
    compareLabels(label1, label2) {
        return label1.id === label2.id;
    }
    removeLabelFromSelection(i) {
        let copy = _.cloneDeep(this.selectedLabels.value);
        copy.splice(i, 1);
        this.selectedLabels.next(copy);
    }
}
LabelingComponent.decorators = [
    { type: Component, args: [{
                selector: 'chain-main-labeling',
                template: "<!--TODO Add CSS-->\n<div id=\"labelEdit\" fxLayout=\"column\" fxLayoutGap=\"20px\">\n    <div> <!--show currently selected selectedLabels-->\n        <mat-chip-list>\n            <mat-chip *ngFor=\"let label of selectedLabels | async; let i = index\"\n                      [ngStyle]=\"{'background-color': label.colorCode}\" (removed)=\"removeLabelFromSelection(i)\">\n                {{label.name}}\n                <mat-icon matChipRemove>cancel</mat-icon>\n            </mat-chip>\n        </mat-chip-list>\n\n    </div>\n\n    <div *ngIf=\"labelEditService.labelManagementShown | async\" fxLayout=\"column\" fxLayoutGap=\"10px\">\n        <!--only visible when the edit button is clicked-->\n        <mat-form-field color=\"accent\">\n            <input matInput placeholder=\"{{'CMD.FIND' | translate}}\">\n        </mat-form-field>\n        <!--Label selection list-->\n        <div fxFlex=\"1 1 20%\">\n            <mat-selection-list #selectionList [ngModel]=\"selectedLabels | async\" [compareWith]=\"compareLabels\"\n                                class=\"select-list\"\n                                (ngModelChange)=\"selectedLabels.next($event)\">\n\n                <mat-list-option *ngFor=\"let label of labelList\" [value]=\"label\"\n                                 [ngStyle]=\"{'background-color': label.colorCode}\">\n                    <div fxLayout=\"row\" fxLayoutAlign=\"space-between\">\n                        <div>{{label.name}}</div>\n                        <mat-icon (click)=\"deleteLabel($event,label.id)\">delete</mat-icon>\n                    </div>\n\n                </mat-list-option>\n\n\n            </mat-selection-list>\n        </div>\n\n        <!--add a custom label-->\n        <div (clickOutside)=\"showAddLabelBox=false\">\n            <form [formGroup]=\"newLabel\">\n                <div class=\"field-wrap\">\n                    <mat-form-field appearance=\"outline\">\n                        <input (click)=\"showAddLabelBox=true\" [ngStyle]=\"{'color': newLabel.value.colorCode}\"\n                               formControlName=\"name\"\n                               autocomplete=\"off\"\n                               matInput placeholder=\"{{'LABEL.ADD_NEW' | translate}}\">\n                    </mat-form-field>\n\n                    <!--the options below are shown only when clicking on the ADD_NEW text field-->\n                    <div class=\"field-wrap\" *ngIf=\"showAddLabelBox\">\n                        <input autocomplete=\"new-labelinput\" matInput formControlName=\"colorCode\">\n\n                        <span [style.background]=\"pickedColor\"\n                              [cpToggle]=\"true\"\n                              [cpDialogDisplay]=\"'inline'\"\n                              [cpDisableInput]=\"true\"\n                              [(colorPicker)]=\"pickedColor\"\n                              (colorPickerChange)=\"colorPickerChange($event)\"></span>\n\n\n                        <button [disabled]=\"newLabel.invalid\" mat-button mat-raised-button (click)=\"createNewLabel()\">\n                            {{'CMD.ADD' | translate}}\n                        </button>\n\n                    </div>\n                </div>\n            </form>\n        </div>\n\n    </div>\n</div>\n",
                providers: [LabelEditService],
                styles: ["#labelEdit .select-list{overflow:auto;height:30vh;overflow-y:scroll}"]
            },] }
];
/** @nocollapse */
LabelingComponent.ctorParameters = () => [
    { type: FormBuilder },
    { type: LabelEditService },
    { type: undefined, decorators: [{ type: Inject, args: [LABEL_ASPECT,] }] }
];
LabelingComponent.propDecorators = {
    labelList: [{ type: Input }],
    labelAdded: [{ type: Output }],
    navigateToAllLabels: [{ type: Output }]
};

class ChainMainLabel {
}
ChainMainLabel.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    LabelTableComponent,
                    LabelingComponent
                ],
                imports: [
                    ColorPickerModule,
                    //     ClickOutsideModule,
                    CommonModule,
                    MatChipsModule,
                    TranslateModule,
                    MatTableModule,
                    MatListModule,
                    FormsModule,
                    ReactiveFormsModule,
                    MatIconModule,
                    MatSelectModule,
                    MatInputModule,
                    MatButtonModule,
                    ClickOutsideModule,
                    FlexModule
                ],
                exports: [
                    LabelTableComponent,
                    LabelingComponent,
                ],
                providers: [],
                entryComponents: [],
                schemas: []
            },] }
];

class GroupTableQueryStore extends QueryTableSource {
    constructor(service, paginator, sort, tableFilter) {
        super(paginator, sort, tableFilter);
        this.service = service;
        this.paginator = paginator;
        this.sort = sort;
        this.tableFilter = tableFilter;
        this.filterSubject = new BehaviorSubject(tableFilter);
    }
    queryTable() {
        let filter = this.findFilter();
        this.applyFilter(filter);
        if (filter.keyword)
            filter.keyword += '*';
        return this.service.queryGroups(filter);
    }
}

//@Injectable({providedIn: 'root'})
class GroupService extends RestAspect {
    constructor(http, configService) {
        super(http, configService);
        this.http = http;
        this.configService = configService;
    }
    // searchGroups(filter: GroupFilter): Observable<Group> {
    //   return this.http.post<Group>(this.formatServiceUrl('/search'), filter);
    // }
    loadGroup(name) {
        return this.http.get(this.formatServiceUrl('/' + name));
    }
    editGroup(group) {
        return this.http.post(this.formatServiceUrl('/'), group);
    }
    queryGroups(filter) {
        return this.query(this.formatServiceUrl('/query'), filter);
    }
    deleteGroup(name) {
        return this.http.delete(this.formatServiceUrl('' + name));
    }
    updateGroup(group) {
        return this.http.put(this.formatServiceUrl(''), group);
    }
    createGroup(value) {
        return this.editGroup(value);
    }
    formatServiceUrl(path = '') {
        return this.configService.formatUrl("mainUrl") + "/groups" + path;
    }
}
GroupService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
GroupService.ctorParameters = () => [
    { type: HttpClient },
    { type: ConfigService }
];

const TAG$2 = 'GroupTableComponent';
class GroupTableComponent {
    constructor(_service) {
        this._service = _service;
        this.displayedColumns = ['info.name', 'roles'];
        this.filter = {};
        this.showToolbar = true;
        this.action = new EventEmitter();
    }
    ngOnInit() {
        let filter = this.filter;
        if (!this.dataSource) {
            this.dataSource = new GroupTableQueryStore(this._service, this.paginator, this.sort, filter);
        }
        console.log(TAG$2, "nativeElement", this.searchElem);
        if (this.searchElem) {
            fromEvent(this.searchElem.nativeElement, 'keyup')
                .pipe(debounceTime(1000), distinctUntilChanged())
                .subscribe(event => {
                let value = this.searchElem.nativeElement.value;
                if (value == '')
                    value = null;
                // let filter = this.dataSource.filterSubject.value;
                let filter = this.filter;
                filter.keyword = value;
                console.log(TAG$2, "nativeElement change", value);
                this.reload();
            });
        }
    }
    reload() {
        this.dataSource.reload();
    }
    onAction(type, payload) {
        this.action.emit({ type: type, value: payload });
    }
}
GroupTableComponent.decorators = [
    { type: Component, args: [{
                selector: 'main-group-table',
                template: "<div class=\"table-layout-1 group-table-layout\">\n\n    <ng-content></ng-content>\n\n  <mat-toolbar class=\"primary-300--bg\" fxLayoutAlign=\"space-between center\">\n    <mat-paginator #paginator [pageIndex]=\"0\" [pageSize]=\"10\" [pageSizeOptions]=\"[5, 10, 25, 100]\">\n    </mat-paginator>\n    <div class=\"field-wrap\">\n      <div class=\"field-box trans-icon\">\n        <input #searchField type=\"text\"/>\n        <button (click)=\"reload()\" type=\"button\">\n          <i><mat-icon>search</mat-icon></i>\n        </button>\n      </div>\n    </div>\n  </mat-toolbar>\n\n  <mat-table class=\"table-hover-1\" #table [dataSource]=\"dataSource\" matSort\n             matSortActive=\"info.name\"\n             matSortDirection=\"asc\"\n             matSortDisableClear>\n\n    <ng-container matColumnDef=\"name\">\n      <mat-header-cell mat-sort-header *matHeaderCellDef>{{'GROUPS.NAME' | translate}}</mat-header-cell>\n      <mat-cell *matCellDef=\"let row\">\n        <span>{{row?.name}}</span></mat-cell>\n    </ng-container>\n\n    <ng-container matColumnDef=\"orgId\">\n      <mat-header-cell mat-sort-header *matHeaderCellDef>{{'GROUPS.ORG_ID' | translate}}</mat-header-cell>\n      <mat-cell *matCellDef=\"let row\">\n        <span>{{row?.orgId}}</span></mat-cell>\n    </ng-container>\n\n    <ng-container matColumnDef=\"type\">\n      <mat-header-cell mat-sort-header *matHeaderCellDef>{{'GROUPS.TYPE' | translate}}</mat-header-cell>\n      <mat-cell *matCellDef=\"let row\">\n        <span>{{row?.type}}</span></mat-cell>\n    </ng-container>\n\n    <ng-container  matColumnDef=\"info.name\">\n      <mat-header-cell mat-sort-header *matHeaderCellDef>{{'GROUPS.NAME' | translate}}</mat-header-cell>\n      <mat-cell *matCellDef=\"let row\" [matTooltip]=\"row.info.desc||row.name\">\n        <span>{{row?.info?.name}}</span></mat-cell>\n    </ng-container>\n\n    <ng-container matColumnDef=\"roles\">\n      <mat-header-cell *matHeaderCellDef>{{'GROUPS.ROLES' | translate}}</mat-header-cell>\n      <mat-cell *matCellDef=\"let row\">\n        <span>{{row?.roles.join(\" , \")}}</span></mat-cell>\n    </ng-container>\n\n    <mat-header-row *matHeaderRowDef=\"displayedColumns\"></mat-header-row>\n    <mat-row *matRowDef=\"let row; columns: displayedColumns;\" (click)=\"onAction('select', row)\">\n    </mat-row>\n\n  </mat-table>\n\n</div>\n\n\n\n"
            },] }
];
/** @nocollapse */
GroupTableComponent.ctorParameters = () => [
    { type: GroupService }
];
GroupTableComponent.propDecorators = {
    displayedColumns: [{ type: Input }],
    filter: [{ type: Input }],
    dataSource: [{ type: Input }],
    showToolbar: [{ type: Input }],
    action: [{ type: Output }],
    paginator: [{ type: ViewChild, args: [MatPaginator, { static: true },] }],
    sort: [{ type: ViewChild, args: [MatSort, { static: true },] }],
    searchElem: [{ type: ViewChild, args: ['searchField', { static: true },] }]
};

class MainGroupModule {
}
MainGroupModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    TranslateModule.forChild({}),
                    ReactiveFormsModule,
                    MatCardModule,
                    MatTableModule,
                    MatTooltipModule,
                    MatPaginatorModule,
                    MatSortModule,
                    MatToolbarModule,
                    MatButtonModule,
                    MatIconModule,
                    FlexLayoutModule,
                    FormsModule,
                    ChainBaseComp
                ],
                declarations: [
                    GroupTableComponent
                ],
                exports: [
                    GroupTableComponent
                ]
            },] }
];

class UserQueryStore extends QueryTableSource {
    constructor(service, paginator, sort, tableFilter) {
        super(paginator, sort, tableFilter);
        this.service = service;
        this.paginator = paginator;
        this.sort = sort;
        this.tableFilter = tableFilter;
        this.filterSubject = new BehaviorSubject(tableFilter);
    }
    queryTable() {
        let filter = this.findFilter();
        this.applyFilter(filter);
        if (filter.keyword)
            filter.keyword += '*';
        return this.service.queryUser(filter);
    }
}

// @Injectable({
//     providedIn: 'root'
// })
class UserService extends RestAspect {
    //Users: User[];
    constructor(http, configService) {
        super(http, configService);
        this.http = http;
        this.configService = configService;
    }
    /** @deprecated */
    searchUser(filter) {
        return this.search(this.formatServiceUrl('/user'), filter);
    }
    queryUser(filter) {
        return this.query(this.formatServiceUrl('/query'), filter);
    }
    loadUser(id) {
        //return this.load<User>(`${this.formatServiceUrl('')}${id}`)
        return this.load(this.formatServiceUrl(`/${id}`))
            .pipe(map(value => this.checkNotNull(value)));
    }
    saveUser(user, method) {
        return this.edit(this.formatServiceUrl(), user, { method: method });
    }
    deleteUser(username) {
        return this.http.delete(this.formatServiceUrl(`/${username}`));
    }
    formatServiceUrl(path = '') {
        return this.configService.formatUrl("mainUrl") + "/users" + path;
    }
}
UserService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
UserService.ctorParameters = () => [
    { type: HttpClient },
    { type: ConfigService }
];

const TAG$3 = 'UserTableComponent';
class UserTableComponent {
    constructor(_service) {
        this._service = _service;
        this.displayedColumns = ['username', 'person.firstName', 'person.lastName', 'created.date'];
        this.filter = {};
        this.showToolbar = true;
        this.action = new EventEmitter();
    }
    ngOnInit() {
        let filter = this.filter;
        if (!this.dataSource) {
            this.dataSource = new UserQueryStore(this._service, this.paginator, this.sort, filter);
        }
        if (this.searchElem) {
            fromEvent(this.searchElem.nativeElement, 'keyup')
                .pipe(debounceTime(1000), distinctUntilChanged())
                .subscribe(event => {
                let value = this.searchElem.nativeElement.value;
                if (value == '')
                    value = null;
                // let filter = this.dataSource.filterSubject.value;
                let filter = this.filter;
                filter.keyword = value;
                this.reload();
            });
        }
    }
    reload() {
        this.dataSource.reload();
    }
    onAction(type, payload) {
        this.action.emit({ type: type, value: payload });
    }
}
UserTableComponent.decorators = [
    { type: Component, args: [{
                selector: 'main-user-table',
                template: "<div class=\"table-layout-1 user-table-layout\">\n\n    <ng-content></ng-content>\n\n  <mat-toolbar class=\"primary-300-bg\" fxLayoutAlign=\"space-between center\">\n    <mat-paginator #paginator [pageIndex]=\"0\" [pageSize]=\"10\" [pageSizeOptions]=\"[5, 10, 25, 100]\">\n    </mat-paginator>\n    <div class=\"field-wrap\">\n      <div class=\"field-box trans-icon\">\n        <input #searchField type=\"text\"/>\n        <button (click)=\"reload()\" type=\"button\">\n          <i><mat-icon>search</mat-icon></i>\n        </button>\n      </div>\n    </div>\n  </mat-toolbar>\n\n  <mat-table class=\"table-hover-1\" #table [dataSource]=\"dataSource\" matSort\n             matSortActive=\"created.date\"\n             matSortDirection=\"desc\"\n             matSortDisableClear>\n\n      <!-- username Column -->\n      <ng-container matColumnDef=\"username\">\n          <mat-header-cell mat-sort-header\n                           *matHeaderCellDef>{{'USER.HEADER.USER_NAME' | translate}}</mat-header-cell>\n          <mat-cell *matCellDef=\"let row\"><span>{{row.username}}</span></mat-cell>\n      </ng-container>\n      <!-- firstName Column -->\n      <ng-container matColumnDef=\"person.firstName\">\n          <mat-header-cell mat-sort-header\n                           *matHeaderCellDef>{{'USER.HEADER.FIRST_NAME' | translate}}</mat-header-cell>\n          <mat-cell *matCellDef=\"let row\"><span>{{row.person?.firstName}}</span></mat-cell>\n      </ng-container>\n\n      <!-- lastName Column -->\n      <ng-container matColumnDef=\"person.lastName\">\n          <mat-header-cell mat-sort-header\n                           *matHeaderCellDef>{{'USER.HEADER.LAST_NAME' | translate}}</mat-header-cell>\n          <mat-cell *matCellDef=\"let row\"><span>{{row.person?.lastName}}</span></mat-cell>\n      </ng-container>\n      <!-- groups Column -->\n      <ng-container matColumnDef=\"groups\">\n          <mat-header-cell mat-sort-header\n                           *matHeaderCellDef>{{'USER.HEADER.GROUPS' | translate}}</mat-header-cell>\n          <mat-cell *matCellDef=\"let row\"><span>{{row.groups}}</span></mat-cell>\n      </ng-container>\n\n      <!-- created date Column -->\n      <ng-container matColumnDef=\"created.date\">\n          <mat-header-cell mat-sort-header *matHeaderCellDef>{{'USER.HEADER.CREATED_DATE' | translate}}</mat-header-cell>\n          <mat-cell *matCellDef=\"let row\"><span>{{row.created?.date | date:'shortDate'}}</span></mat-cell>\n      </ng-container>\n\n\n      <mat-header-row *matHeaderRowDef=\"displayedColumns\"></mat-header-row>\n    <mat-row *matRowDef=\"let row; columns: displayedColumns;\" (click)=\"onAction('select', row)\">\n    </mat-row>\n\n  </mat-table>\n\n</div>\n\n\n\n"
            },] }
];
/** @nocollapse */
UserTableComponent.ctorParameters = () => [
    { type: UserService }
];
UserTableComponent.propDecorators = {
    displayedColumns: [{ type: Input }],
    filter: [{ type: Input }],
    dataSource: [{ type: Input }],
    showToolbar: [{ type: Input }],
    action: [{ type: Output }],
    paginator: [{ type: ViewChild, args: [MatPaginator, { static: true },] }],
    sort: [{ type: ViewChild, args: [MatSort, { static: true },] }],
    searchElem: [{ type: ViewChild, args: ['searchField', { static: true },] }]
};

class MainUserModule {
}
MainUserModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    TranslateModule.forChild({}),
                    ReactiveFormsModule,
                    MatCardModule,
                    MatTableModule,
                    MatTooltipModule,
                    MatPaginatorModule,
                    MatSortModule,
                    MatToolbarModule,
                    MatButtonModule,
                    MatIconModule,
                    FlexLayoutModule,
                    FormsModule,
                    ChainBaseComp
                ],
                declarations: [
                    UserTableComponent
                ],
                exports: [
                    UserTableComponent
                ]
            },] }
];

class SettingQueryStore extends QueryTableSource {
    constructor(service, paginator, sort, tableFilter) {
        super(paginator, sort, tableFilter);
        this.service = service;
        this.paginator = paginator;
        this.sort = sort;
        this.tableFilter = tableFilter;
        this.filterSubject = new BehaviorSubject(tableFilter);
    }
    queryTable() {
        let filter = this.findFilter();
        this.applyFilter(filter);
        if (filter.keyword)
            filter.keyword += '*';
        return this.service.querySettings(filter);
    }
}

class SettingService extends RestAspect {
    constructor(http, configService) {
        super(http, configService);
        this.http = http;
        this.configService = configService;
    }
    // /** @deprecated */
    // searchSettings(filter:SettingFilter): Observable<SearchResult<Setting>> {
    //     return this.search<Setting>(this.formatServiceUrl('settings'),filter);
    // }
    querySettings(filter) {
        return this.query(this.formatServiceUrl('/query'), filter);
    }
    loadSetting(module, shortName) {
        return this.load(`${this.formatServiceUrl()}/${module}/${shortName}`)
            .pipe(map(value => this.checkNotNull(value)));
    }
    loadByKey(key) {
        return this.load(`${this.formatServiceUrl()}/load?key=${key}`)
            .pipe(map(value => this.checkNotNull(value)));
    }
    editSetting(setting) {
        return this.edit(this.formatServiceUrl(), setting, { method: 'put' });
    }
    deleteSetting(module, shortName) {
        return this.http.delete(`${this.formatServiceUrl()}${module}/${shortName}`);
    }
    formatServiceUrl(path = '') {
        return this.configService.formatUrl("mainUrl") + "/settings" + path;
    }
}
SettingService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
SettingService.ctorParameters = () => [
    { type: HttpClient },
    { type: ConfigService }
];

const TAG$4 = 'UserTableComponent';
class SettingTableComponent {
    constructor(_service) {
        this._service = _service;
        this.displayedColumns = ['name', 'module', 'value', 'change.date'];
        this.filter = {};
        this.showToolbar = true;
        this.action = new EventEmitter();
    }
    ngOnInit() {
        if (this.customColumns && this.customColumns.length > 0) {
            let columnDef = this.customColumns.map(c => c.columnDef);
            this.displayedColumns.push(...columnDef);
        }
    }
    ngAfterViewInit() {
        let filter = this.filter;
        if (!this.dataSource) {
            this.dataSource = new SettingQueryStore(this._service, this.paginator, this.sort, filter);
            //queryStore(this._service, this.paginator, this.sort, filter);
        }
        if (this.searchElem) {
            fromEvent(this.searchElem.nativeElement, 'keyup')
                .pipe(debounceTime(1000), distinctUntilChanged())
                .subscribe(event => {
                let value = this.searchElem.nativeElement.value;
                if (value == '')
                    value = null;
                // let filter = this.dataSource.filterSubject.value;
                let filter = this.filter;
                filter.keyword = value;
                this.reload();
            });
        }
    }
    reload() {
        this.dataSource.reload();
    }
    onAction(type, payload) {
        this.action.emit({ type: type, value: payload });
    }
}
SettingTableComponent.decorators = [
    { type: Component, args: [{
                selector: 'main-setting-table',
                template: "<div class=\"table-layout-1 setting-table-layout\">\n\n    <ng-content></ng-content>\n\n    <mat-toolbar *ngIf=\"showToolbar\" class=\"primary-300--bg\" fxLayoutAlign=\"space-between center\">\n        <mat-paginator #paginator [pageIndex]=\"0\" [pageSize]=\"10\" [pageSizeOptions]=\"[5, 10, 25, 100]\">\n        </mat-paginator>\n        <div class=\"field-wrap\">\n            <div class=\"field-box trans-icon\">\n                <input #searchField type=\"text\"/>\n                <button (click)=\"reload()\" type=\"button\">\n                    <i>\n                        <mat-icon>search</mat-icon>\n                    </i>\n                </button>\n            </div>\n        </div>\n    </mat-toolbar>\n\n    <mat-toolbar *ngIf=\"!showToolbar\" class=\"primary-300--bg\" fxLayoutAlign=\"space-between center\">\n        <div fxFlex=\"1 1 auto\"></div>\n        <mat-paginator #paginator [pageIndex]=\"0\" [pageSize]=\"10\" [pageSizeOptions]=\"[5, 10, 25, 100]\">\n        </mat-paginator>\n    </mat-toolbar>\n\n    <mat-table class=\"table-hover-1\" #table [dataSource]=\"dataSource\" matSort\n               matSortActive=\"change.date\"\n               matSortDirection=\"desc\"\n               matSortDisableClear>\n\n        <!-- SETTINGname Column -->\n        <ng-container matColumnDef=\"name\">\n            <mat-header-cell mat-sort-header\n                             *matHeaderCellDef>{{'SETTING.HEADER.SETTING_NAME' | translate}}</mat-header-cell>\n            <mat-cell *matCellDef=\"let row\"><span>{{row?.name}}</span></mat-cell>\n        </ng-container>\n\n        <!-- firstName Column -->\n        <ng-container matColumnDef=\"module\">\n            <mat-header-cell mat-sort-header\n                             *matHeaderCellDef>{{'SETTING.HEADER.MODULE' | translate}}</mat-header-cell>\n            <mat-cell *matCellDef=\"let row\"><span>{{row?.module}}</span></mat-cell>\n        </ng-container>\n\n        <!-- lastName Column -->\n        <ng-container matColumnDef=\"value\">\n            <mat-header-cell mat-sort-header\n                             *matHeaderCellDef>{{'SETTING.HEADER.VALUE' | translate}}</mat-header-cell>\n            <mat-cell *matCellDef=\"let row\"><span>{{row?.value}}</span></mat-cell>\n        </ng-container>\n        <!-- groups Column -->\n        <ng-container matColumnDef=\"orgId\">\n            <mat-header-cell mat-sort-header\n                             *matHeaderCellDef>{{'SETTING.HEADER.ORG' | translate}}</mat-header-cell>\n            <mat-cell *matCellDef=\"let row\"><span>{{row?.orgId}}</span></mat-cell>\n        </ng-container>\n\n        <!-- created date Column -->\n        <ng-container matColumnDef=\"change.date\">\n            <mat-header-cell mat-sort-header\n                             *matHeaderCellDef>{{'SETTING.HEADER.CHANGE_DATE' | translate}}</mat-header-cell>\n            <!--<mat-cell *matCellDef=\"let row\"><span>{{row?.change?.date | date:'shortDate'}}</span></mat-cell>-->\n            <mat-cell *matCellDef=\"let row\">\n                <base-date [data]=\"row.change?.date\" format=\"date\" formatTip=\"false\"\n                           [matTooltip]=\"row.change?.user\"></base-date>\n            </mat-cell>\n        </ng-container>\n\n        <ng-container matColumnDef=\"created.date\">\n            <mat-header-cell mat-sort-header *matHeaderCellDef>{{'COMMON.CREATED_DATE' | translate}}</mat-header-cell>\n            <!--<mat-cell *matCellDef=\"let row\"><span>{{row?.change?.date | date:'shortDate'}}</span></mat-cell>-->\n            <mat-cell *matCellDef=\"let row\">\n                <base-date [data]=\"row.created?.date\" format=\"date\" formatTip=\"false\"\n                           [matTooltip]=\"row.created?.user\"></base-date>\n            </mat-cell>\n        </ng-container>\n\n        <!--custom columns -->\n        <ng-container *ngFor=\"let column of customColumns\" [cdkColumnDef]=\"column.columnDef\">\n            <mat-header-cell *cdkHeaderCellDef>{{ column.header }}</mat-header-cell>\n            <div id=\"observe-wrapper\">\n                <mat-cell *cdkCellDef=\"let row\" [innerHTML]=\"column.cell(row)\"></mat-cell>\n            </div>\n        </ng-container>\n\n\n        <mat-header-row *matHeaderRowDef=\"displayedColumns\"></mat-header-row>\n        <mat-row *matRowDef=\"let row; columns: displayedColumns;\" (click)=\"onAction('select', row)\">\n        </mat-row>\n\n    </mat-table>\n\n</div>\n\n\n\n",
                encapsulation: ViewEncapsulation.None
            },] }
];
/** @nocollapse */
SettingTableComponent.ctorParameters = () => [
    { type: SettingService }
];
SettingTableComponent.propDecorators = {
    displayedColumns: [{ type: Input }],
    filter: [{ type: Input }],
    dataSource: [{ type: Input }],
    showToolbar: [{ type: Input }],
    action: [{ type: Output }],
    paginator: [{ type: ViewChild, args: [MatPaginator, { static: false },] }],
    sort: [{ type: ViewChild, args: [MatSort, { static: false },] }],
    searchElem: [{ type: ViewChild, args: ['searchField', { static: false },] }],
    customColumns: [{ type: Input }]
};

class MainSettingModule {
}
MainSettingModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    TranslateModule.forChild({}),
                    ReactiveFormsModule,
                    MatCardModule,
                    MatTableModule,
                    MatTooltipModule,
                    MatPaginatorModule,
                    MatSortModule,
                    MatToolbarModule,
                    MatButtonModule,
                    MatIconModule,
                    FlexLayoutModule,
                    FormsModule,
                    ChainBaseComp,
                    CdkTableModule
                ],
                declarations: [
                    SettingTableComponent
                ],
                exports: [
                    SettingTableComponent
                ], schemas: [NO_ERRORS_SCHEMA]
            },] }
];

/**
 * Data source for the settings table view. This class should
 * encapsulate all logic for fetching and manipulating the displayed data
 * (including sorting, pagination, and filtering).
 */
class SettingTableDatasource extends QueryTableSource {
    constructor(settingService, paginator, sort, filter = {}) {
        super(paginator, sort, filter);
        this.settingService = settingService;
        this.paginator = paginator;
        this.sort = sort;
        this.filter = filter;
    }
    queryTable() {
        let filter = this.findFilter();
        this.applyFilter(filter);
        return this.settingService.querySettings(filter);
    }
    initReloadMutations() {
        // server-side filtering
        return [this.filterSubject];
        // all client-side
        //return [];
    }
    searchData(data) {
        let filter = this.findFilter();
        if (filter.keyword) {
            console.debug(this.constructor.name, "searchData:", filter);
            //let regEx = new RegExp("^"+filter.keyword.replace('*', '.*'), 'i');
            let regEx = new RegExp(filter.keyword.replace('*', '.*'), 'i');
            data = data.filter(value => regEx.test(value.name)
                || regEx.test(value.shortName)
                || regEx.test(value.desc));
        }
        return super.searchData(data);
    }
}

/*
 * Public API Surface of test
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ChainMainLabel, GroupService, GroupTableComponent, GroupTableQueryStore, LabelEditService, LabelTableComponent, LabelingComponent, MainGroupModule, MainSettingModule, MainUserModule, SettingQueryStore, SettingService, SettingTableComponent, SettingTableDatasource, UserQueryStore, UserService, UserTableComponent };
//# sourceMappingURL=yukawa-chain-main-angular-comp.js.map
